<template>
	<ywDialog
		v-model="dialogIsShow"
		:headerIcon="dialogHeaderIcon"
		:title="dialogTitle"
		width="470"
		@dlgClosed="closeDialog"
		@close="closeDialog"
		@submit="submitFormValue"
	>
		<el-form :model="dialogFormValue" ref="dialogFormRef" :rules="dialogFormRules" label-width="86">
			<el-form-item label="工单编号" prop="id" disabled>
				<el-input v-model="dialogFormValue.id" readonly></el-input>
			</el-form-item>
			<el-form-item label="工单名称" prop="title">
				<el-input v-model="dialogFormValue.title"></el-input>
			</el-form-item>
			<el-form-item label="工单类型" prop="type">
				<el-select v-model="dialogFormValue.type">
					<el-option
						v-for="item in [
							{ ID: '设备维修', Name: '设备维修' },
							{ ID: '流量异常', Name: '流量异常' },
							{ ID: '压力异常', Name: '压力异常' },
							{ ID: '水质异常', Name: '水质异常' },
							{ ID: '用户投诉', Name: '用户投诉' },

						]"
						:key="item.ID"
						:value="item.ID"
						:label="item.Name"
					></el-option>
				</el-select>
			</el-form-item>
			<el-form-item label="工单内容" prop="content">
				<el-input v-model="dialogFormValue.content" type="textarea" :rows="3"></el-input>
			</el-form-item>
			<!-- <el-form-item label="上报人" prop="question">
				<el-select v-model="dialogFormValue.prompt">
					<el-option
						v-for="item in [
							{ ID: '1', Name: '张三' },
							{ ID: '2', Name: '李四' },
						]"
						:key="item.ID"
						:value="item.ID"
						:label="item.Name"
					></el-option>
				</el-select>
			</el-form-item> -->

			<el-form-item label="备注" prop="remark">
				<el-input v-model="dialogFormValue.remark" type="textarea" :rows="3"></el-input>
			</el-form-item>
			<el-form-item label="附件图片" prop="pic">
				<el-upload
					ref="uploadRef"
					action="#"
					list-type="picture-card"
					:auto-upload="true"
					:http-request="uploadRequest"
					:on-success="handleUploadSuccess"
				>
					<el-icon><Plus /></el-icon>

					<template #file="{ file }">
						<div>
							<img class="el-upload-list__item-thumbnail" :src="file.url" alt="" />
							<span class="el-upload-list__item-actions">
								<span class="el-upload-list__item-preview" @click="handlePictureCardPreview(file)">
									<el-icon><zoom-in /></el-icon>
								</span>
								<!-- <span v-if="!disabled" class="el-upload-list__item-delete" @click="handleDownload(file)">
								<el-icon><Download /></el-icon>
							</span> -->
								<span class="el-upload-list__item-delete" @click="handleRemove(file)">
									<el-icon><Delete /></el-icon>
								</span>
							</span>
						</div>
					</template>
				</el-upload>
			</el-form-item>
		</el-form>
		<el-dialog v-model="dialogVisible">
			<img w-full :src="dialogImageUrl" alt="Preview Image" />
		</el-dialog>
	</ywDialog>
</template>

<script setup lang="ts" name="WorkOrderDlg">
import ywDialog from '/@/components/dialog/yw-dialog.vue';

import type { FormInstance, FormRules, UploadFile, UploadRawFile, UploadRequestOptions } from 'element-plus';
import { ElMessage, ElMessageBox, ElUpload } from 'element-plus';

import { computed, ref, watch } from 'vue';
// import { useTableSort } from '/@/hooks/useTableSort';
// import { useValidateUniqueness } from '/@/hooks/useValidateUniqueness';
import { deepClone } from '/@/utils/other';

import { storeToRefs } from 'pinia';
import { useUserInfo } from '/@/stores/userInfo';
import { formatDate } from '/@/utils/formatTime';
import { toFormData } from '/@/utils/util';
import { useCompRef } from '/@/utils/types';

const props = defineProps(['item']);
const emit = defineEmits(['update', 'insert','cancelSubmit']);
//#region ====================== 增加、修改记录操作, dialog init======================
const isEditDialog = ref(false);
const dialogTitle = computed(() => {
	return isEditDialog.value ? '创建工单' : '创建工单';
});
const dialogHeaderIcon = computed(() => {
	return isEditDialog.value ? 'ele-Edit' : 'ele-Plus';
});
const dialogFormValue = ref(null);
const dialogIsShow = defineModel({
	type: Boolean,
});
const dialogFormRef = ref<FormInstance>(null);

const dialogFormRules = ref<FormRules>({
	// title: [{ required: true, message: '请输入标题', trigger: 'blur' }],
	// prompt: [{ required: true, message: '请输入提示词', trigger: 'blur' }],
});
const openOperateDialog = (row?) => {
	if (row) {
		isEditDialog.value = true;
		const { title,type,content,remark,} = row;
		dialogFormValue.value = deepClone({id: `GM_${formatDate(new Date(),'YYYY_mmdd_HHMMSS')}`,title,type,content,remark});
	} else {
		isEditDialog.value = false;
		dialogFormValue.value = {id: `GM_${formatDate(new Date(),'YYYY_mmdd_HHMMSS')}`, name: '', type: '', content: '', note: ''};
	}
};
const closeDialog = () => {
	dialogIsShow.value = false;
	dialogFormRef.value.clearValidate();
	if(notSubmit){
		emit('cancelSubmit','取消提交')
	}
};
const stores = useUserInfo();
const { userInfos } = storeToRefs(stores);

const submitFormValue = async () => {
	emit('insert')
	notSubmit = false;
	closeDialog();
	ElMessage.success('创建工单成功');
	return;
	const valid = await dialogFormRef.value.validate().catch(() => {});
	if (!valid) return;

	const sendForm = { ...dialogFormValue.value };
	const updateTime = formatDate(new Date());
	if (isEditDialog.value) {
		const res = await supervisorAdminApi.updateSupervisor(sendForm);
		emit('update', { ...dialogFormValue.value, update_time: updateTime.slice(0, 10) });

		closeDialog();
		ElMessage.success('修改页面成功');
	} else {
		const res = await supervisorAdminApi.addSupervisor(sendForm);
		const newData = {
			id: res.agent_id,
			...dialogFormValue.value,
			create_time: updateTime.slice(0, 10),
			update_time: updateTime.slice(0, 10),
			creator: userInfos.value.userName,
		};
		emit('insert', newData);
		// tableData.value.push(newData);
		closeDialog();
		ElMessage.success('添加页面成功');
	}
};

//#endregion
//#region ====================== 操作按钮 ======================
const dialogImageUrl = ref('');
const dialogVisible = ref(false);
const handlePictureCardPreview = (file: UploadFile) => {
	dialogImageUrl.value = file.url!;
	dialogVisible.value = true;
};

const uploadRef = useCompRef(ElUpload);
const removeFile = (file: UploadFile | UploadRawFile) => {
	// if (type === ImageCatagoryEnum.Background) {
	// 	bgUploadRef.value?.uploadRef?.handleRemove(file);
	// } else if (type === ImageCatagoryEnum.Element) {
	// 	eleUploadRef.value?.uploadRef?.handleRemove(file);
	// } else if (type === ImageCatagoryEnum.ImgTranslator) {
	// 	imgTranslatorRef.value?.uploadRef?.handleRemove(file);
	// }
	uploadRef.value?.handleRemove(file);
};
const handleRemove = (file: UploadFile) => {
	ElMessageBox.confirm(`确定删除当前图片：【${file.name}】?`, '提示', {
		confirmButtonText: '确定',
		cancelButtonText: '取消',
		type: 'warning',
	}).then(async () => {
		removeFile(file);
		// 删除文件记录
		// const res = await bankImageApi.DeleteArtImageBankImageByID({
		// 	ID: (file as any).id,
		// });
		// if (res?.Code === 0) {
		// 	if (res.Data) {
		// 		removeFile(file, type);
		// 		ElMessage.success('删除图片成功');
		// 	} else {
		// 		ElMessage.error('删除图片失败');
		// 	}
		// } else {
		// 	ElMessage.error('删除图片失败' + (res?.Message ? `，${JSON.stringify(res.Message)}` : ''));
		// }
	});
};

const uploadRequest = (options: UploadRequestOptions) => {
	const { name, size } = options.file;
	const formData = toFormData({});
	formData.append('file', options.file);
};

const handleUploadSuccess = (value) => {};

//#endregion

let notSubmit = true;
watch(
	() => dialogIsShow.value,
	(val) => {
		if (!val) return;
		notSubmit = true;
		openOperateDialog(props.item);
	}
);
</script>
<style scoped lang="scss"></style>
